searchData={"items":[{"type":"module","title":"Membrane.File.NewSeekEvent","doc":"An event sent by the `Membrane.File.Source` with `seekable?: true` option,\nright after receiving `Membrane.File.SeekSourceEvent`.\nAn element that steers the seekable file source with `Membrane.File.SeekSourceEvent`\ncan assume that all the buffers received after receiving that event are\nthe buffers ordered by that `Membrane.File.SeekSourceEvent`.","ref":"Membrane.File.NewSeekEvent.html"},{"type":"module","title":"Membrane.File.SeekSinkEvent","doc":"Event that triggers seeking or insertion to a file in `Membrane.File.Sink`.\n\n`inspect(__MODULE__)` allows to control behaviour of `Membrane.File.Sink` when writing to a file\nby seeking to given `position` (relative to beginning of file, current position or end of file).\nAll buffers that arrive after that event are being written starting from the `position`.\n\nIf overwriting isn't the desired behaviour, one can set `insert?` flag to `true`. This will trigger\nsplitting the file into two parts containing bytes before and after `position`. All buffers following\nsuch an event will be appended to the first part. Inserting has considerable performance impact,\nespecially if done repeatedly, so it should be used only as a fallback for variable-length data.\nFor all other cases, one can fill unknown bytes with eg. `0`s and simply overwrite them later.","ref":"Membrane.File.SeekSinkEvent.html"},{"type":"type","title":"Membrane.File.SeekSinkEvent.offset_t/0","doc":"","ref":"Membrane.File.SeekSinkEvent.html#t:offset_t/0"},{"type":"type","title":"Membrane.File.SeekSinkEvent.position_t/0","doc":"Specifies the position to which the seek is performed.\n\nThe meaning is the same as for the `Location` argument in https://www.erlang.org/doc/man/file.html#position-2.","ref":"Membrane.File.SeekSinkEvent.html#t:position_t/0"},{"type":"type","title":"Membrane.File.SeekSinkEvent.t/0","doc":"","ref":"Membrane.File.SeekSinkEvent.html#t:t/0"},{"type":"module","title":"Membrane.File.SeekSourceEvent","doc":"Event that triggers seeking and reading in `Membrane.File.Source` working in\n`seekable?: true` mode.\n\nWhen `inspect(__MODULE__)` is received by the source, the source starts reading\ndata from the given position in file, specified by the `:start` field of the event's\nstruct. The source reads up to `size_to_read` bytes of the data from file (it can\nread less if the file ends).\nIf the event is set with `last?: true`, once `size_to_read` bytes are read or the\nfile ends, the source will return `end_of_stream` action on the `:output` pad.","ref":"Membrane.File.SeekSourceEvent.html"},{"type":"type","title":"Membrane.File.SeekSourceEvent.offset_t/0","doc":"","ref":"Membrane.File.SeekSourceEvent.html#t:offset_t/0"},{"type":"type","title":"Membrane.File.SeekSourceEvent.position_t/0","doc":"Specifies the position to which the seek is performed.\n\nThe meaning is the same as for the `Location` argument in https://www.erlang.org/doc/man/file.html#position-2.","ref":"Membrane.File.SeekSourceEvent.html#t:position_t/0"},{"type":"type","title":"Membrane.File.SeekSourceEvent.t/0","doc":"","ref":"Membrane.File.SeekSourceEvent.html#t:t/0"},{"type":"module","title":"Membrane.File.Sink","doc":"Element that creates a file and stores incoming buffers there (in binary format).\n\nWhen `Membrane.File.SeekSinkEvent` is received, the element starts writing buffers starting\nfrom `position`. By default, it overwrites previously stored bytes. You can set `insert?`\nfield of the event to `true` to start inserting new buffers without overwriting previous ones.\nPlease note, that inserting requires rewriting the file, what negatively impacts performance.\nFor more information refer to `Membrane.File.SeekSinkEvent` moduledoc.","ref":"Membrane.File.Sink.html"},{"type":"module","title":"Element options - Membrane.File.Sink","doc":"Passed via struct `t:Membrane.File.Sink.t/0`\n\n- `location`  \n\n  ```\n  Path.t()\n  ```\n  \n  ***Required***  \n  Path of the output file","ref":"Membrane.File.Sink.html#module-element-options"},{"type":"module","title":"Pads - Membrane.File.Sink","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:manual`\nDemand unit: | `:buffers`","ref":"Membrane.File.Sink.html#module-pads"},{"type":"function","title":"Membrane.File.Sink.options/0","doc":"Returns description of options available for this module","ref":"Membrane.File.Sink.html#options/0"},{"type":"type","title":"Membrane.File.Sink.t/0","doc":"Struct containing options for `Membrane.File.Sink`","ref":"Membrane.File.Sink.html#t:t/0"},{"type":"module","title":"Membrane.File.Sink.Multi","doc":"Element that writes buffers to a set of files. File is switched on event.\n\nFiles are named according to `naming_fun` passed in options.\nThis function receives sequential number of file and should return string.\nIt defaults to `path/to/file0.ext`, `path/to/file1.ext`, ...\n\nThe event type, which starts writing to a next file is passed by `split_event` option.\nIt defaults to `Membrane.File.SplitEvent`.","ref":"Membrane.File.Sink.Multi.html"},{"type":"module","title":"Element options - Membrane.File.Sink.Multi","doc":"Passed via struct `t:Membrane.File.Sink.Multi.t/0`\n\n- `location`  \n\n  ```\n  Path.t()\n  ```\n  \n  ***Required***  \n  Base path to the file, will be passed to the naming function\n\n\n- `extension`  \n\n  ```\n  String.t()\n  ```\n  \n  Default value: `\"\"`  \n  Extension of the file, should be preceeded with dot (.). It is\n  passed to the naming function.\n\n\n\n- `naming_fun`  \n\n  ```\n  (Path.t(), non_neg_integer, String.t() -> Path.t())\n  ```\n  \n  Default value: `&Membrane.File.Sink.Multi.default_naming_fun/3`  \n  Function accepting base path, sequential number and file extension,\n  and returning file path as a string. Default one generates\n  path/to/file0.ext, path/to/file1.ext, ...\n\n\n\n- `split_event`  \n\n  ```\n  Membrane.Event.t()\n  ```\n  \n  Default value: `Membrane.File.SplitEvent`  \n  Event causing switching to a new file","ref":"Membrane.File.Sink.Multi.html#module-element-options"},{"type":"module","title":"Pads - Membrane.File.Sink.Multi","doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:manual`\nDemand unit: | `:buffers`","ref":"Membrane.File.Sink.Multi.html#module-pads"},{"type":"function","title":"Membrane.File.Sink.Multi.default_naming_fun/3","doc":"","ref":"Membrane.File.Sink.Multi.html#default_naming_fun/3"},{"type":"function","title":"Membrane.File.Sink.Multi.options/0","doc":"Returns description of options available for this module","ref":"Membrane.File.Sink.Multi.html#options/0"},{"type":"type","title":"Membrane.File.Sink.Multi.t/0","doc":"Struct containing options for `Membrane.File.Sink.Multi`","ref":"Membrane.File.Sink.Multi.html#t:t/0"},{"type":"module","title":"Membrane.File.Source","doc":"Element that reads chunks of data from given file and sends them as buffers\nthrough the output pad.\n\nCan work in two modes, determined by the `seekable?` option.","ref":"Membrane.File.Source.html"},{"type":"module","title":"Element options - Membrane.File.Source","doc":"Passed via struct `t:Membrane.File.Source.t/0`\n\n- `location`  \n\n  ```\n  Path.t()\n  ```\n  \n  ***Required***  \n  Path to the file\n\n\n- `chunk_size`  \n\n  ```\n  pos_integer()\n  ```\n  \n  Default value: `2048`  \n  Size of chunks being read\n\n\n\n- `seekable?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  With `seekable?: false`, the source will start reading data from the file exactly the moment it starts\n  playing and will read it till the end of file, setting the `end_of_stream` action on the `:output` pad\n  when the reading is done.\n  With `seekable?: true`, the process of reading is driven by receiving `Membrane.File.SeekSourceEvent` events.\n  The source working in `seekable?: true` mode won't send any data before that event is received.\n  For more information about how to steer reading in `seekable?: true` mode, see: `Membrane.File.SeekSourceEvent`.","ref":"Membrane.File.Source.html#module-element-options"},{"type":"module","title":"Pads - Membrane.File.Source","doc":"### `:output`\n\nAccepted formats:\n```\n%RemoteStream{type: :bytestream}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:manual`\nDemand unit: | `nil`","ref":"Membrane.File.Source.html#module-pads"},{"type":"function","title":"Membrane.File.Source.options/0","doc":"Returns description of options available for this module","ref":"Membrane.File.Source.html#options/0"},{"type":"type","title":"Membrane.File.Source.t/0","doc":"Struct containing options for `Membrane.File.Source`","ref":"Membrane.File.Source.html#t:t/0"},{"type":"module","title":"Membrane.File.SplitEvent","doc":"Default event that closes current and opens new file in\n`Membrane.File.Sink.Multi`.","ref":"Membrane.File.SplitEvent.html"},{"type":"extras","title":"Membrane File plugin","doc":"# Membrane File plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_file_plugin.svg)](https://hex.pm/packages/membrane_file_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_file_plugin/)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_file_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_file_plugin)\n\nMembrane plugin for reading and writing to files.\n\nIt is part of [Membrane Multimedia Framework](https://membraneframework.org).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane File plugin","doc":"The package can be installed by adding `membrane_file_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_file_plugin, \"~> 0.16.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage examples - Membrane File plugin","doc":"#","ref":"readme.html#usage-examples"},{"type":"extras","title":"File.Sink and File.Source - Membrane File plugin","doc":"`Source` and `Sink` elements allow reading from and writing to a file, respectively.\nThe pipeline in `./examples/sink_and_source.exs` will copy the contents of that script to `/tmp/example.exs`\n\n#","ref":"readme.html#file-sink-and-file-source"},{"type":"extras","title":"File.MultiSink - Membrane File plugin","doc":"`MultiSink` allows writing to multiple files, with the input being split into parts.\nThe example in `./examples/sink_multi.exs` will generate 0-filled input file of 1024 bytes (`input.bin`)\nand copy first 10-bytes to `/tmp/output0.bin` and the rest to `/tmp/output1.bin`.","ref":"readme.html#file-multisink"},{"type":"extras","title":"Copyright and License - Membrane File plugin","doc":"Copyright 2018, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2018 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}